@@ -1,6 +1,7 @@
 from time import sleep
 
 from ravenpackapi.exceptions import api_method
+from ravenpackapi.upload.upload_utils import retry_on_too_early
 
 FILE_FIELDS = (
     'file_id', 'file_name', 'folder_id',
@@ -45,8 +46,7 @@ class File(object):
 
     @api_method
     def get_status(self):
-        response = self.api.request('%s/files/%s/status' % (self.api._UPLOAD_BASE_URL, self.file_id))
-        self.status = response.json()['status']
+        self.get_metadata(force_refresh=True)
         return self.status
 
     @api_method
@@ -65,8 +65,9 @@ class File(object):
 
     @api_method
     def save_original(self, filename):
-        response = self.api.request('%s/files/%s' % (self.api._UPLOAD_BASE_URL, self.file_id),
-                                    stream=True)
+        response = retry_on_too_early(self.api.request,
+                             '%s/files/%s' % (self.api._UPLOAD_BASE_URL, self.file_id),
+                                      stream=True)
         with open(filename, 'wb') as f:
             for chunk in response.iter_content(chunk_size=self.api._CHUNK_SIZE):
                 f.write(chunk)
@@ -74,12 +75,13 @@ class File(object):
     @api_method
     def save_analytics(self, filename, output_format='application/json'):
         self.wait_for_completion()
-        response = self.api.request('%s/files/%s/analytics' % (self.api._UPLOAD_BASE_URL, self.file_id,),
-                                    headers=dict(
-                                        Accept=output_format,
-                                        **self.api.headers
-                                    ),
-                                    stream=True)
+        response = retry_on_too_early(self.api.request,
+                             '%s/files/%s/analytics' % (self.api._UPLOAD_BASE_URL, self.file_id,),
+                                      headers=dict(
+                                 Accept=output_format,
+                                 **self.api.headers
+                             ),
+                                      stream=True)
         with open(filename, 'wb') as f:
             for chunk in response.iter_content(chunk_size=self.api._CHUNK_SIZE):
                 f.write(chunk)
@@ -87,11 +89,12 @@ class File(object):
     @api_method
     def get_analytics(self, output_format='application/json'):
         self.wait_for_completion()
-        response = self.api.request('%s/files/%s/analytics' % (self.api._UPLOAD_BASE_URL, self.file_id,),
-                                    headers=dict(
-                                        Accept=output_format,
-                                        **self.api.headers
-                                    ))
+        response = retry_on_too_early(self.api.request,
+                             '%s/files/%s/analytics' % (self.api._UPLOAD_BASE_URL, self.file_id,),
+                                      headers=dict(
+                                 Accept=output_format,
+                                 **self.api.headers
+                             ))
         if output_format == 'application/json':
             return response.json()
         else:
@@ -100,8 +103,9 @@ class File(object):
     @api_method
     def save_annotated(self, filename):
         self.wait_for_completion()
-        response = self.api.request('%s/files/%s/annotated' % (self.api._UPLOAD_BASE_URL, self.file_id),
-                                    stream=True)
+        response = retry_on_too_early(self.api.request,
+                             '%s/files/%s/annotated' % (self.api._UPLOAD_BASE_URL, self.file_id),
+                                      stream=True)
         with open(filename, 'wb') as f:
             for chunk in response.iter_content(chunk_size=self.api._CHUNK_SIZE):
                 f.write(chunk)
@@ -109,13 +113,17 @@ class File(object):
     @api_method
     def get_annotated(self):
         self.wait_for_completion()
-        response = self.api.request('%s/files/%s/annotated' % (self.api._UPLOAD_BASE_URL, self.file_id))
+        response = retry_on_too_early(self.api.request,
+                             '%s/files/%s/annotated' % (self.api._UPLOAD_BASE_URL, self.file_id)
+                                      )
         return response.text
 
     @api_method
     def delete(self):
-        response = self.api.request('%s/files/%s' % (self.api._UPLOAD_BASE_URL, self.file_id),
-                                    method='delete')
+        response = retry_on_too_early(self.api.request,
+                             '%s/files/%s' % (self.api._UPLOAD_BASE_URL, self.file_id),
+                                      method='delete'
+                                      )
         return response
 
     @api_method
